<?php
/**
 * Copyright 2011 Bas de Nooijer. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 * 1. Redistributions of source code must retain the above copyright notice,
 *    this list of conditions and the following disclaimer.
 *
 * 2. Redistributions in binary form must reproduce the above copyright notice,
 *    this listof conditions and the following disclaimer in the documentation
 *    and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDER AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 *
 * The views and conclusions contained in the software and documentation are
 * those of the authors and should not be interpreted as representing official
 * policies, either expressed or implied, of the copyright holder.
 *
 * @copyright Copyright 2011 Bas de Nooijer <solarium@raspberry.nl>
 * @license http://github.com/basdenooijer/solarium/raw/master/COPYING
 *
 * @package Solarium
 * @subpackage Query
 */

/**
 * Update query add (documents) command
 */
class Solarium_Query_Update_Command_Add extends Solarium_Query_Update_Command
{

    /**
     * Documents to add
     *
     * @var array
     */
    protected $_documents = array();

    public function getType()
    {
        return Solarium_Query_Update_Command::ADD;
    }

    /**
     * Add a single document
     *
     * @param object $document
     * @return Solarium_Query_Update_Add Provides fluent interface
     */
    public function addDocument($document)
    {
        $this->_documents[] = $document;

        return $this;
    }

    /**
     * Add multiple documents
     *
     * @param array $documents
     * @return Solarium_Query_Update_Add Provides fluent interface
     */
    public function addDocuments($documents)
    {
        $this->_documents = array_merge($this->_documents, $documents);

        return $this;
    }

    public function getDocuments()
    {
        return $this->_documents;
    }

    /**
     * @param boolean $overwrite
     * @return Solarium_Query_Update_Add Provides fluent interface
     */
    public function setOverwrite($overwrite)
    {
        return $this->_setOption('overwrite', $overwrite);
    }

    /**
     * @return boolean
     */
    public function getOverwrite()
    {
        return $this->getOption('overwrite');
    }

    /**
     * @param boolean $commitWithin
     * @return Solarium_Query_Update_Add Provides fluent interface
     */
    public function setCommitWithin($commitWithin)
    {
        return $this->_setOption('commitwithin', $commitWithin);
    }

    /**
     * @return boolean
     */
    public function getCommitWithin()
    {
        return $this->getOption('commitwithin');
    }
}